==> staffology-0.1.1-py3-none-any.whl: staffology/api/employer/get_group_memberships_employer.py <==
from typing import Any, Dict, List, Optional

import httpx

from ...client import Client
from ...models.employer_group_membership import EmployerGroupMembership
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{id}/groups".format(client.base_url, id=id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[List[EmployerGroupMembership]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = EmployerGroupMembership.from_dict(
                response_200_item_data
            )

            response_200.append(response_200_item)

        return response_200
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[List[EmployerGroupMembership]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
) -> Response[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
) -> Optional[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    return sync_detailed(
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
) -> Response[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
) -> Optional[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
        )
    ).parsed

==> staffology-0.1.4-py3-none-any.whl: staffology/api/employer/get_group_memberships_employer.py <==
from typing import Any, Dict, List, Optional

import httpx
from staffology.propagate_exceptions import raise_staffology_exception

from ...client import Client
from ...models.employer_group_membership import EmployerGroupMembership
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/employers/{id}/groups".format(client.base_url, id=id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[List[EmployerGroupMembership]]:
    if response.status_code == 200:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = EmployerGroupMembership.from_dict(
                response_200_item_data
            )

            response_200.append(response_200_item)

        return response_200
    return raise_staffology_exception(response)


def _build_response(
    *, response: httpx.Response
) -> Response[List[EmployerGroupMembership]]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
) -> Response[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
) -> Optional[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    return sync_detailed(
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
) -> Response[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
) -> Optional[List[EmployerGroupMembership]]:
    """Get Employer Groups

    Args:
        id (str):

    Returns:
        Response[List[EmployerGroupMembership]]
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
        )
    ).parsed
